==> haskell-lsp-test0.14.0-0.14.0.2-209-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test0.14.0.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-test
version:              0.14.0.2
visibility:           public
id:                   lsp-test-0.14.0.2-3vTHywXTfWvKfRCkAvEZoE
key:                  lsp-test-0.14.0.2-3vTHywXTfWvKfRCkAvEZoE
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  17719e6c9aa69d587c73684af134c52e
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.4.0.1-IJjWhhL4nCHG7Sf3kGEFlI:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.4.0.1-IJjWhhL4nCHG7Sf3kGEFlI:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test0.14.0
hs-libraries:         HSlsp-test-0.14.0.2-3vTHywXTfWvKfRCkAvEZoE
depends:
    Diff-0.4.1-BX7ePMXM8kOEj0lpdSYnwr
    Glob-0.10.2-JfA0ye8zAkc8ATfWN2Qrof
    aeson-2.1.2.1-HdmwuFbnNgF6PqutsUaf6Y
    aeson-pretty-0.8.10-54a6nQVBHpDKtebdqWCdpb
    ansi-terminal-1.0.2-EudAPB7rRCyDJBI0UXDeTd
    async-2.2.5-5GErM17TKUiKLh0botO2cH base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-8TTHoZfFEcNByedkE9Rv7V
    conduit-parse-0.2.1.1-88zZIGt8SXcD2AnL6d2aLI containers-0.6.7
    data-default-0.7.1.2-6Zl8APX45CF9ONl13lbZ09 directory-1.3.7.1
    filepath-1.4.2.2 lens-5.3-L5hp9JbMaZ3ARz3g7EupwI
    lsp-types-1.4.0.1-IJjWhhL4nCHG7Sf3kGEFlI mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav process-1.6.18.0
    some-1.0.6-J9WA0PZXfbZI3cJIKKtOIb text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-DaOkK38PYRa9pF7ZwbG4ZB

haddock-interfaces:   /usr/share/doc/haskell-lsp-test0.14.0/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test0.14.0/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-test0.14.0-0.14.0.2-210-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test0.14.0.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-test
version:              0.14.0.2
visibility:           public
id:                   lsp-test-0.14.0.2-C9RtlPDFzWpKlp50kbyDfn
key:                  lsp-test-0.14.0.2-C9RtlPDFzWpKlp50kbyDfn
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  0a8d92f65c9e683554d983bde19303ce
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.4.0.1-CFnjmfen6ZuChzXwwikFk8:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.4.0.1-CFnjmfen6ZuChzXwwikFk8:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test0.14.0
hs-libraries:         HSlsp-test-0.14.0.2-C9RtlPDFzWpKlp50kbyDfn
depends:
    Diff-0.4.1-BX7ePMXM8kOEj0lpdSYnwr
    Glob-0.10.2-JfA0ye8zAkc8ATfWN2Qrof
    aeson-2.1.2.1-nFo3VMHABFBaVDPPKfnuT
    aeson-pretty-0.8.10-FEdTNv6fEiP4zvH2lfwaXH
    ansi-terminal-1.0.2-EudAPB7rRCyDJBI0UXDeTd
    async-2.2.5-5GErM17TKUiKLh0botO2cH base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-BrVAMLporIm8aoMwut0RwH
    conduit-parse-0.2.1.1-2g5iGM9sa6K5KBcQnVgXqI containers-0.6.7
    data-default-0.7.1.2-6Zl8APX45CF9ONl13lbZ09 directory-1.3.7.1
    filepath-1.4.2.2 lens-5.3-9QFGiHrGYTq5sUNhwFgilM
    lsp-types-1.4.0.1-CFnjmfen6ZuChzXwwikFk8 mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav process-1.6.18.0
    some-1.0.6-J9WA0PZXfbZI3cJIKKtOIb text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-DaOkK38PYRa9pF7ZwbG4ZB

haddock-interfaces:   /usr/share/doc/haskell-lsp-test0.14.0/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test0.14.0/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
